@@ -24,31 +24,21 @@
 
 #include "platform.h"
 #include <microhttpd.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif /* HAVE_UNISTD_H */
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif /* HAVE_SYS_STAT_H */
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif /* HAVE_FCNTL_H */
 
 #define PAGE "<html><head><title>File not found</title></head><body>File not found</body></html>"
 
-
-static ssize_t
-file_reader (void *cls,
-             uint64_t pos,
-             char *buf,
-             size_t max)
-{
-  FILE *file = cls;
-
-  (void)  fseek (file, pos, SEEK_SET);
-  return fread (buf, 1, max, file);
-}
-
-
-static void
-free_callback (void *cls)
-{
-  FILE *file = cls;
-  fclose (file);
-}
-
+#ifndef S_ISREG
+#define S_ISREG(x) (S_IFREG == (x & S_IFREG))
+#endif /* S_ISREG */
 
 static int
 ahc_echo (void *cls,
@@ -62,7 +52,6 @@ ahc_echo (void *cls,
   static int aptr;
   struct MHD_Response *response;
   int ret;
-  FILE *file;
   int fd;
   struct stat buf;
 
@@ -76,24 +65,26 @@ ahc_echo (void *cls,
       return MHD_YES;
     }
   *ptr = NULL;                  /* reset when done */
-  file = fopen (&url[1], "rb");
-  if (NULL != file)
+  /* WARNING: direct usage of url as filename is for example only!
+   * NEVER pass received data directly as parameter to file manipulation
+   * functions. Always check validity of data before using.
+   */
+  if (NULL != strstr(url, "../")) /* Very simplified check! */
+    fd = -1; /* Do not allow usage of parent directories. */
+  else
+    fd = open (url + 1, O_RDONLY);
+  if (-1 != fd)
     {
-      fd = fileno (file);
-      if (-1 == fd)
-        {
-          (void) fclose (file);
-          return MHD_NO; /* internal error */
-        }
       if ( (0 != fstat (fd, &buf)) ||
            (! S_ISREG (buf.st_mode)) )
         {
           /* not a regular file, refuse to serve */
-          fclose (file);
-          file = NULL;
+          if (0 != close (fd))
+            abort ();
+          fd = -1;
         }
     }
-  if (NULL == file)
+  if (-1 == fd)
     {
       response = MHD_create_response_from_buffer (strlen (PAGE),
 						  (void *) PAGE,
@@ -103,13 +94,11 @@ ahc_echo (void *cls,
     }
   else
     {
-      response = MHD_create_response_from_callback (buf.st_size, 32 * 1024,     /* 32k page size */
-                                                    &file_reader,
-                                                    file,
-                                                    &free_callback);
+      response = MHD_create_response_from_fd64 (buf.st_size, fd);
       if (NULL == response)
 	{
-	  fclose (file);
+	  if (0 != close (fd))
+            abort ();
 	  return MHD_NO;
 	}
       ret = MHD_queue_response (connection, MHD_HTTP_OK, response);
@@ -129,7 +118,7 @@ main (int argc, char *const *argv)
       printf ("%s PORT\n", argv[0]);
       return 1;
     }
-  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_DEBUG,
+  d = MHD_start_daemon (MHD_USE_THREAD_PER_CONNECTION | MHD_USE_INTERNAL_POLLING_THREAD | MHD_USE_ERROR_LOG,
                         atoi (argv[1]),
                         NULL, NULL, &ahc_echo, PAGE, MHD_OPTION_END);
   if (d == NULL)
