@@ -12,11 +12,25 @@
 #if defined(__cplusplus)
 extern "C" {
 #endif /* __cplusplus */
-void	*tdelete(const void * __restrict, void ** __restrict,
-	    int (*)(const void *, const void *));
-void	*tfind(const void *, void * const *,
-	    int (*)(const void *, const void *));
-void	*tsearch(const void *, void **, int (*)(const void *, const void *));
+
+
+void	*
+tdelete (const void * __restrict,
+         void ** __restrict,
+         int (*)(const void *, const void *));
+
+
+void	*
+tfind (const void *,
+       void * const *,
+       int (*)(const void *, const void *));
+
+
+void	*
+tsearch (const void *,
+         void **,
+         int (*)(const void *, const void *));
+
 #if defined(__cplusplus)
 };
 #endif /* __cplusplus */
